"use client"

import type React from "react"

import { useState, useRef, useEffect } from "react"
import { useTheme } from "next-themes"
import { cn } from "@/lib/utils"

interface InteractivesProps {
  children: React.ReactNode
  className?: string
}

export function Interactives({ children, className = "" }: InteractivesProps) {
  const containerRef = useRef<HTMLDivElement>(null)
  const [mousePosition, setMousePosition] = useState({ x: 50, y: 50 })
  const [isHovering, setIsHovering] = useState(false)
  const { theme } = useTheme()
  const [mounted, setMounted] = useState(false)

  useEffect(() => {
    setMounted(true)
  }, [])

  const handleMouseMove = (e: React.MouseEvent) => {
    if (!containerRef.current) return

    const rect = containerRef.current.getBoundingClientRect()
    setMousePosition({
      x: e.clientX - rect.left,
      y: e.clientY - rect.top,
    })
  }

  if (!mounted) return <div className={className}>{children}</div>

  const isDarkMode = theme === "dark"

  const getInteractives = () => {
    const width = containerRef.current?.offsetWidth || 0
    const height = containerRef.current?.offsetHeight || 0

    // Mouse pos to %
    const xPercent = (mousePosition.x / width) * 100
    const yPercent = (mousePosition.y / height) * 100

    if (isDarkMode) {
      return {
        backgroundImage: `
          linear-gradient(to right, transparent, transparent),
          radial-gradient(
            circle at ${xPercent}% ${yPercent}%, 
            rgba(192, 132, 252, 0.6) 0%, 
            transparent 50%
          )
        `,
        opacity: isHovering ? 1 : 0,
      }
    } else {
      return {
        backgroundImage: `
          linear-gradient(to right, transparent, transparent),
          radial-gradient(
            circle at ${xPercent}% ${yPercent}%, 
            rgba(178, 127, 226, 0.5) 0%, 
            transparent 60%
          )
        `,
        border: isHovering ? '1px solid rgba(147, 51, 234, 0.5)' : '1px solid transparent',
        opacity: isHovering ? 1 : 0,
      }
    }
  }

  return (
    <div
      ref={containerRef}
      className={cn("relative", className)}
      onMouseMove={handleMouseMove}
      onMouseEnter={() => setIsHovering(true)}
      onMouseLeave={() => setIsHovering(false)}
    >
      <div className="absolute inset-0 rounded-[inherit] pointer-events-none border-glow-container">
        <div
          className="w-full h-full rounded-[inherit] border border-transparent transition-all duration-300"
          style={getInteractives()}
        />
      </div>
      {children}
    </div>
  )
}
